@@ -7,7 +7,6 @@ Allows for programmatically interacting with conda's configuration files (e.g.,
 
 from __future__ import annotations
 
-import json
 import os
 import sys
 from argparse import SUPPRESS
@@ -19,7 +18,7 @@ from pathlib import Path
 from textwrap import wrap
 from typing import TYPE_CHECKING
 
-from ..base.constants import DEFAULTS_CHANNEL_NAME
+from ..common.configuration import DEFAULT_CONDARC_FILENAME
 
 if TYPE_CHECKING:
     from argparse import ArgumentParser, Namespace, _SubParsersAction
@@ -267,8 +266,7 @@ def format_dict(d):
 
 
 def parameter_description_builder(name, context=None, plugins=False):
-    from ..auxlib.entity import EntityEncoder
-    from ..common.serialize import yaml_round_trip_dump
+    from ..common.serialize import json, yaml_round_trip_dump
 
     # Keeping this for backward-compatibility, in case no context instance is provided
     if context is None:
@@ -281,7 +279,7 @@ def parameter_description_builder(name, context=None, plugins=False):
     aliases = details["aliases"]
     string_delimiter = details.get("string_delimiter")
     element_types = details["element_types"]
-    default_value_str = json.dumps(details["default_value"], cls=EntityEncoder)
+    default_value_str = json.dumps(details["default_value"])
 
     if details["parameter_type"] == "primitive":
         builder.append(
@@ -558,6 +556,8 @@ def _read_rc(path: str | os.PathLike | Path) -> dict:
 
 
 def _write_rc(path: str | os.PathLike | Path, config: dict) -> None:
+    from ruamel.yaml.representer import RoundTripRepresenter
+
     from .. import CondaError
     from ..base.constants import (
         ChannelPriority,
@@ -567,7 +567,7 @@ def _write_rc(path: str | os.PathLike | Path, config: dict) -> None:
         SatSolverChoice,
         UpdateModifier,
     )
-    from ..common.serialize import yaml, yaml_round_trip_dump
+    from ..common.serialize import yaml_round_trip_dump
 
     # Add representers for enums.
     # Because a representer cannot be added for the base Enum class (it must be added for
@@ -576,24 +576,12 @@ def _write_rc(path: str | os.PathLike | Path, config: dict) -> None:
     def enum_representer(dumper, data):
         return dumper.represent_str(str(data))
 
-    yaml.representer.RoundTripRepresenter.add_representer(
-        SafetyChecks, enum_representer
-    )
-    yaml.representer.RoundTripRepresenter.add_representer(
-        PathConflict, enum_representer
-    )
-    yaml.representer.RoundTripRepresenter.add_representer(
-        DepsModifier, enum_representer
-    )
-    yaml.representer.RoundTripRepresenter.add_representer(
-        UpdateModifier, enum_representer
-    )
-    yaml.representer.RoundTripRepresenter.add_representer(
-        ChannelPriority, enum_representer
-    )
-    yaml.representer.RoundTripRepresenter.add_representer(
-        SatSolverChoice, enum_representer
-    )
+    RoundTripRepresenter.add_representer(SafetyChecks, enum_representer)
+    RoundTripRepresenter.add_representer(PathConflict, enum_representer)
+    RoundTripRepresenter.add_representer(DepsModifier, enum_representer)
+    RoundTripRepresenter.add_representer(UpdateModifier, enum_representer)
+    RoundTripRepresenter.add_representer(ChannelPriority, enum_representer)
+    RoundTripRepresenter.add_representer(SatSolverChoice, enum_representer)
 
     try:
         Path(path).write_text(yaml_round_trip_dump(config))
@@ -636,16 +624,14 @@ def set_keys(*args: tuple[str, Any], path: str | os.PathLike | Path) -> None:
 
 def execute_config(args, parser):
     from .. import CondaError
-    from ..auxlib.entity import EntityEncoder
     from ..base.context import (
-        _warn_defaults_deprecation,
         context,
         sys_rc_path,
         user_rc_path,
     )
     from ..common.io import timeout
     from ..common.iterators import groupby_to_dict as groupby
-    from ..common.serialize import yaml_round_trip_load
+    from ..common.serialize import json, yaml_round_trip_load
     from ..core.prefix_data import PrefixData
 
     # Override context for --file operations with --show/--describe
@@ -668,9 +654,6 @@ def execute_config(args, parser):
                         for source, values in context.collect_all().items()
                     },
                     sort_keys=True,
-                    indent=2,
-                    separators=(",", ": "),
-                    cls=EntityEncoder,
                 )
             )
         else:
@@ -726,15 +709,7 @@ def execute_config(args, parser):
             del d["plugins"]
 
         if context.json:
-            stdout_write(
-                json.dumps(
-                    d,
-                    sort_keys=True,
-                    indent=2,
-                    separators=(",", ": "),
-                    cls=EntityEncoder,
-                )
-            )
+            stdout_write(json.dumps(d, sort_keys=True))
         else:
             # Add in custom formatting
             if "custom_channels" in d:
@@ -791,9 +766,6 @@ def execute_config(args, parser):
                     json.dumps(
                         json_descriptions,
                         sort_keys=True,
-                        indent=2,
-                        separators=(",", ": "),
-                        cls=EntityEncoder,
                     )
                 )
             else:
@@ -830,9 +802,6 @@ def execute_config(args, parser):
                             for name in provided_parameters
                         ],
                         sort_keys=True,
-                        indent=2,
-                        separators=(",", ": "),
-                        cls=EntityEncoder,
                     )
                 )
             else:
@@ -848,7 +817,7 @@ def execute_config(args, parser):
         rc_path = sys_rc_path
     elif args.env:
         if context.active_prefix:
-            rc_path = join(context.active_prefix, ".condarc")
+            rc_path = join(context.active_prefix, DEFAULT_CONDARC_FILENAME)
         else:
             rc_path = user_rc_path
     elif args.file:
@@ -856,7 +825,7 @@ def execute_config(args, parser):
     elif args.prefix or args.name:
         prefix_data = PrefixData.from_context()
         prefix_data.assert_environment()
-        rc_path = str(prefix_data.prefix_path / ".condarc")
+        rc_path = str(prefix_data.prefix_path / DEFAULT_CONDARC_FILENAME)
     else:
         rc_path = user_rc_path
 
@@ -928,15 +897,6 @@ def execute_config(args, parser):
         for key, item in arg:
             key, subkey = key.split(".", 1) if "." in key else (key, None)
 
-            channels_is_unpopulated = key == "channels" and key not in rc_config
-
-            if channels_is_unpopulated:
-                # don't warn if users are literally trying to remove the warning
-                # by explicitly adding the defaults channel to the channels list
-                if item != DEFAULTS_CHANNEL_NAME:
-                    _warn_defaults_deprecation()
-                rc_config[key] = [DEFAULTS_CHANNEL_NAME]
-
             if key in sequence_parameters:
                 arglist = rc_config.setdefault(key, [])
             elif key == "plugins" and subkey in plugin_sequence_parameters:
@@ -957,9 +917,6 @@ def execute_config(args, parser):
                 raise CouldntParseError(f"key {key!r} should be a list, not {bad}.")
 
             if item in arglist:
-                # don't warn if users are literally trying to remove the warning
-                if channels_is_unpopulated and item == DEFAULTS_CHANNEL_NAME:
-                    continue
                 message_key = key + "." + subkey if subkey is not None else key
                 # Right now, all list keys should not contain duplicates
                 location = "top" if prepend else "bottom"
